## 0.0.23

This new version includes a variety of enhancements and new features, including the addition of a coding bot panel app, a refactor of the CLI, and updates to the notebooks and tutorial materials. The version also includes the integration of pyzotero to dependencies and the beginning of a prototype for coding and diffbots in a library of bots.

### New Features

- Added a coding bot panel app (a139420) (Eric Ma)
- Refactored the CLI for better performance and usability (b067193) (Eric Ma)
- Updated the scratch notebook (c0a4e2b) (Eric Ma)
- Added a code tutorial notebook to help users understand how to use the application (ae42c64) (Eric Ma)
- Added instructions in the codingbot source file to provide more context for the code tutorial bot (79236f) (Eric Ma)
- Added more notebooks to save work and enhance the user experience (891e570) (Eric Ma)
- Added pyzotero to dependencies to enhance the functionality of the application (1d55eb2) (Eric Ma)
- Began the prototype of coding and diffbots in a library of bots to expand the application's capabilities (f26c789) (Eric Ma)
- Updated the blog text demo for better user understanding (ae9c539) (Eric Ma)
- Updated base bots to use the updated llamaindex for improved performance (baad16c) (Eric Ma)

### Bug Fixes

- Fixed the placement of noqa DAR101 for better code quality (d73b14f) (Eric Ma)

### Deprecations

- No deprecations in this release.
